summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/views/about_chrome_view.h
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-25 17:30:23 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-25 17:30:23 +0000
commit5168c72cdf678fe73cb6cca42330c9398355ed68 (patch)
tree571819bf8181ecd971059d8d768c1a47b68527a6 /chrome/browser/ui/views/about_chrome_view.h
parent39f8389fea86381271c2966ca17f947ec4e8dcb6 (diff)
downloadchromium_src-5168c72cdf678fe73cb6cca42330c9398355ed68.zip
chromium_src-5168c72cdf678fe73cb6cca42330c9398355ed68.tar.gz
chromium_src-5168c72cdf678fe73cb6cca42330c9398355ed68.tar.bz2
views: Move LinkController into its own header file.
While I'm here, did some changes: - Rename the LinkController interface to LinkListener. - Move the interface to link_listener.h - Rename the event from LinkActivated to LinkClicked. - Changed the get/set accessors to listener()/set_listener(). - Add OVERRIDE to LinkClicked methods. BUG=None TEST=None R=sky@chromium.org Review URL: http://codereview.chromium.org/6881099 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@82885 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/views/about_chrome_view.h')
-rw-r--r--chrome/browser/ui/views/about_chrome_view.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/chrome/browser/ui/views/about_chrome_view.h b/chrome/browser/ui/views/about_chrome_view.h
index 6393de0..8dca0db 100644
--- a/chrome/browser/ui/views/about_chrome_view.h
+++ b/chrome/browser/ui/views/about_chrome_view.h
@@ -6,9 +6,11 @@
#define CHROME_BROWSER_UI_VIEWS_ABOUT_CHROME_VIEW_H_
#pragma once
+#include "base/basictypes.h"
+#include "base/compiler_specific.h"
#include "views/controls/image_view.h"
#include "views/controls/label.h"
-#include "views/controls/link.h"
+#include "views/controls/link_listener.h"
#include "views/view.h"
#include "views/window/dialog_delegate.h"
@@ -36,7 +38,7 @@ class Profile;
////////////////////////////////////////////////////////////////////////////////
class AboutChromeView : public views::View,
public views::DialogDelegate,
- public views::LinkController
+ public views::LinkListener
#if defined(OS_WIN) || defined(OS_CHROMEOS)
, public GoogleUpdateStatusListener
#endif
@@ -73,8 +75,9 @@ class AboutChromeView : public views::View,
virtual bool Accept();
virtual views::View* GetContentsView();
- // Overridden from views::LinkController:
- virtual void LinkActivated(views::Link* source, int event_flags);
+ // Overridden from views::LinkListener:
+ virtual void LinkClicked(views::Link* source, int event_flags) OVERRIDE;
+
#if defined(OS_WIN) || defined(OS_CHROMEOS)
// Overridden from GoogleUpdateStatusListener:
virtual void OnReportResults(GoogleUpdateUpgradeResult result,